function [sel_t] = addbot(P0, t0, tLayer1, numbers);
%ADDBOT - Selects bottom metal triangles for a group of layers
%
% Syntax:
%   [sel_T] = addbot(P0, t0, tLayer1, numbers);
%
% Description:
%   ADDBOT calls TRISELECT and adds selected triangles.
%
% Input:
%   P0 - array of nodes for the volumetric mesh - base layer 
%   t0 - array of triangles for the base planar mesh (from STRUCT2D)
%   tLayer1 - array of faces for the volumetric mesh - base layer 
%   numbers - array of layer numbers
%
% Output:
%   sel_t - cell array of index arrays of triangles to be removed from the
%           set of faces [included in the bottom metal surface?], one layer
%           per cell.  A value of {NaN} (i.e., a cell array containing the
%           value NaN) is currently used to indicate that the user closed
%           the window.
%
% See also: TRISELECT.

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu
% Authors: S. Makarov, A. Marut

if length(numbers)==0
    str = ' nothing'; % shouldn't be called with numbers empty anyway
    sel_t = [1:size(tLayer1, 2)];
    return;
elseif length(numbers)==1
    str = [ ' layer #' num2str(numbers)];
else
    str = [ ' layers ' num2str(numbers)];
end

%   Select triangles
string          = strcat('Select bottom metal faces of ',str); 
Sel             = triselect(P0, tLayer1(:,1:size(t0, 2)), string);
if isnan(Sel)
    sel_t       = {NaN};  %[1:size(tLayer1, 2)];
else
    sel_t       = setdiff(1:size(tLayer1, 2), Sel);
    temp = {};
    for n=numbers
        temp{end+1} = sel_t;
    end
    sel_t = temp;
end


