function [sel_f] = addfeed(P0, e0, tLayer1, z, numbers, String);
%ADDFEED - Selects designated metal edges for a group of layers 
%
% Syntax:
%   [sel_f] = addfeed(P0, e0, tLayer1, z, numbers);
%
% Description:
%   ADDVIA calls TRISELECT and adds selected feed edges.
%
% Input:
%   P0 - array of nodes for the volumetric mesh - base layer 
%   e0 - array of edges (triangles) for the base planar mesh
%   tLayer1 - array of faces for the volumetric mesh - base layer 
%   z       - z-coordinate of feed edges
%   numbers - array of layer numbers
%
% Output:
%   sel_f - array of feeding edge centers
%
% See also: TRISELECT.

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu
% Authors: S. Makarov, A. Marut

if length(numbers)==0
    str = ' nothing'; % shouldn't be called with numbers empty anyway
    sel_t = [1:size(tLayer1, 2)];
    return;
elseif length(numbers)==1
    str = [ ' layer #' num2str(numbers)];
else
    str = [ ' layers ' num2str(numbers)];
end

%   Select triangles - via
string          = strcat(String, str); 
Sel             = triselect(P0, e0, string);
s               = size(tLayer1, 2);
if isnan(Sel)
    sel_f       = NaN; 
else
    sel_f       = [];
    for m = 1:s
        CFaceXY(1:2,m) =  sum(P0(1:2, tLayer1(1:3,m)),2)/3;
    end    
    for m = 1:length(Sel)
        P       = P0(1:2, e0(1, Sel(m)))+P0(1:2, e0(2, Sel(m)));
        P       = P/2;
        P(3)    = z;
        sel_f   = [sel_f P];      
    end 
end