function varargout = view3d(varargin)
%VIEW3D - base file for mesh visualization
%
% Syntax:
%   view3d(P, T, FacesBoundary, reserved);
%
% Description:
%   VIEW3D displays a window that allows the user to choose how to view the
%   mesh.  The user may view the outer faces or all of the edges; choosing
%   either one causes it to be displayed in a new window.
%
% Input:
%   P - array of nodes for the volumetric mesh
%   T - array of tetrahedra T for the volumetric mesh
%   FacesBoundary - array of boundary faces for the volumetric mesh
%   reserved - reserved variable

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu
% Author: A. Marut

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @view3d_OpeningFcn, ...
                   'gui_OutputFcn',  @view3d_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before view3d is made visible.
function view3d_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to view3d (see VARARGIN)

% P, T, FacesBoundary, parameter
handles.P             = varargin{1};
handles.T             = varargin{2};
handles.FacesBoundary = varargin{3};
handles.t             = varargin{4};
handles.const         = varargin{5};  
parameter             = varargin{end};
if 1 <= parameter && parameter <= 5
%     rb = eval(['handles.radiobutton' int2str(parameter)]);
%     init_callback_str  = ['radiobutton' int2str(parameter) '_Callback'];
%     init_callback_func = str2func(init_callback_str);
%     feval(init_callback_func, rb, eventdata, handles);
end
    
% Choose default command line output for view3d
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes view3d wait for user response (see UIRESUME)
uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = view3d_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

s = pwd;
cd ..;
pathremove;
cd(s);
varargout{1} = [];


% --- Executes on button press in radiobutton1.
function radiobutton1_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

handles = deselect_radio_btns(handles);
set(hObject, 'Value', get(hObject, 'Max'));
if ~isempty(handles.T)
    figure;
    viewer (handles.P, handles.FacesBoundary);
end
guidata(hObject, handles);


% --- Executes on button press in radiobutton2.
function radiobutton2_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

handles = deselect_radio_btns(handles);
set(hObject, 'Value', get(hObject, 'Max'));
if ~isempty(handles.T)
    figure;
    P = handles.P;
    tetramesh(handles.T', [P(1,:)' P(2,:)' P(3,:)'], handles.const.Epsilon_r, 'FaceAlpha', 0.10);
end
guidata(hObject, handles);


% --- Executes on button press in radiobutton3.
function radiobutton3_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

handles = deselect_radio_btns(handles);
set(hObject, 'Value', get(hObject, 'Max'));
figure;
viewer (handles.P, handles.t);


% --- Executes on button press in radiobutton4.
function radiobutton4_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

handles = deselect_radio_btns(handles);
set(hObject, 'Value', get(hObject, 'Max'));
figure;
FB      = handles.FacesBoundary;
FB(4,:) = 0.5;
if ~isempty(handles.t) 
    viewer (handles.P, [FB handles.t]);
else
    viewer (handles.P, [FB]);
end

function h = deselect_radio_btns(handles)
% handles    structure with handles and user data (see GUIDATA)
% Returns the handles with properties updated to deselect the four radio
% buttons.
set(handles.radiobutton1, 'Value', get(handles.radiobutton1, 'Min'));
set(handles.radiobutton2, 'Value', get(handles.radiobutton2, 'Min'));
set(handles.radiobutton3, 'Value', get(handles.radiobutton3, 'Min'));
set(handles.radiobutton4, 'Value', get(handles.radiobutton4, 'Min'));
h = handles;


