%BASIS - Computes parameters for dielectric tetrahedra including the basis functions
%
% Syntax:
%   STRUCT0 = basis(P, T, Faces, Edges, AT, const);
% 
% Description:
%   BASIS returns a structure STRUCT0, which defines parameters of the
%   tetrahedral mesh including the basis functions.
%
% Input:
%   P - array of nodes
%   T - array of tetrahedra
%   Faces - array of dielectric faces
%   Edges - array of dielectric edges
%   AT - array of adjacent tetrahedra for every dielectric face
%   const - structure array of constants including dielectric data
%           for every tetrahedron
%
% Output:
%   STRUCT0 - structure array with the fields indicated below
%
%   STRUCT0.EdgesFNI;
%   STRUCT0.EdgesFN;
%   STRUCT0.EdgesTNI;
%   STRUCT0.EdgesTN;
%   STRUCT0.BasisTC;
%   STRUCT0.VolumeT;
%   STRUCT0.CenterT;
%   STRUCT0.CenterF;
%   STRUCT0.AreaF;
%   STRUCT0.DiffContrast_real; 
%   STRUCT0.DiffContrast_imag; 
%   STRUCT0.Contrast_real;     
%   STRUCT0.Contrast_imag;
%
%   For a description of these fields, please see DIELECTRIC.

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu
% Authors: S. Kulkarni, S. Makarov
