%INT_FACE_FACE - Computes the double potential integrals for dielectric faces.
%
% Syntax:
%   FF = int_face_face(P, faces, coeffS, weightsS, Radius);     
% 
% Description:
%   INT_FACE_FACE returns a structure FF which provides all potential double 
%   integrals of the static kernel (1/R) over faces in the dielectric volume
%   including the self-integrals if the distance between two faces is smaller
%   than or equal to a given dimensionless distance - Radius. If Radius <1
%   then only the double self integrals are computed. 
%
%   These data are saved in FF.SS.  The integration is carried out using
%   analytical formulae for the inner integral and the Gaussian integration
%   for the outer integral.  The indices of the observation and integration
%   faces are saved in FF.IS and FF.JS, respectively.
%
% Inputs:
%   P       - array of nodes
%   faces   - array of faces
%   CoeffS  - node coefficients for a Gaussian formula
%   WeightsS- weights for a Gaussian formula
%   Radius  - threshold parameter - compared to the ratio distance 
%   between face centers/square root of two sizes. Each size is 
%   defined as a maximum distance from the center of the simplex to its
%   vertex.
%
% Output:
%   FF.SS - array of potential integrals (divided by face areas) - scalar
%   FF.IS - indexes of observation tetrahedra
%   FF.JS - indexes of integration tetrahedra

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu
% Authors: S. Makarov, S. Kulkarni
