%INT_TET_TET - Computes the double potential integrals for dielectric tetrahedra.
%
% Syntax:
%   TT = int_tet_tet(P, T, coeffT, weightsT, IndexT, Radius); 
% 
% Description:
%   INT_TET_TET returns a structure TT which provides all potential double 
%   integrals of the static kernel (1/R) over tetrahedra in the dielectric volume
%   including the self-integrals if the distance between two tetrahedra is smaller
%   than or equal to a given dimensionless distance - Radius. If Radius <1
%   then only the double self integrals are computed. 
%
%   These data are saved in TT.SS.  The integration is carried out using
%   analytical formulae for the inner integral and the Gaussian integration
%   for the outer integral.  The indices of the observation and integration 
%   tetrahedra are saved in TT.IS and TT.JS, respectively.
%
% Inputs:
%   P       - array of nodes
%   T       - array of tetrahedra
%   CoeffT  - node coefficients for a Gaussian formula
%   WeightsT- weights for a Gaussian formula
%   IndexT  - number of integration points
%   Radius  - threshold parameter - compared to the ratio distance 
%   between tetrahedra centers/square root of two sizes. Each size is 
%   defined as a maximum distance from the center of the simplex to its vertex.

%
% Output:
%   TT.SS - array of potential integrals (divided by tetrahedra volumes) -
%   scalar
%   TT.IS - indexes of observation tetrahedra
%   TT.JS - indexes of integration tetrahedra

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu
% Authors: S. Makarov, S. Kulkarni
