%INT_TET_TRI - Computes the double potential integrals for dielectric tetrahedra/metal faces.
%
% Syntax:
%   Tt  = int_tet_tri(P, P, t, T, coeffS, weightsS, Radius);  
% 
% Description:
%   INT_TET_TRI returns a structure Tt which provides all potential double 
%   integrals of the static kernel (1/R) over tetrahedra and RWG BFs for metal faces
%   including the self-integrals if the distance between a tetrahedron and a metal face
%   is smaller than or equal to a given dimensionless distance - Radius. If Radius <1
%   then no self-integrals are computed. 
%
%   These data are saved in Tt.SS.  The integration is carried out using
%   analytical formulae for the inner integral and the Gaussian integration
%   for the outer integral.  The indices of the observation faces and integration 
%   tetrahedra are saved in TT.IS and TT.JS, respectively.
%
% Inputs:
%   P       - array of nodes
%   T       - array of tetrahedra
%   CoeffS  - node coefficients for a Gaussian formula
%   WeightsS- weights for a Gaussian formula
%   Radius  - threshold parameter - compared to the ratio distance 
%   between tetrahedra/triangle centers/square root of two sizes. Each size is 
%   defined as a maximum distance from the center of the simplex to its
%   vertex.
%
% Output:
%   Tt.SS - array of potential integrals (divided by tetrahedron volume/face
%   area) with 3x1 vector elements (rho_i) assembled as a 1D array 
%   Tt.IS - indexes of observation faces
%   Tt.JS - indexes of integration tetrahedra

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu
% Authors: S. Makarov, S. Kulkarni
