%INT_TRI_TRI - Computes the double potential integrals for metal faces.
%
% Syntax:
%   tt  = int_tri_tri(P, t, coeffS, weightsS, Radius);       
% 
% Description:
%   INT_TRI_TRI returns a structure tt which provides all potential double 
%   integrals of the static kernel (1/R) over metal faces with RWG BFs 
%   including the self-integrals if the distance between 
%   two faces is smaller than or equal to a given dimensionless distance - Radius. 
%   If Radius <1 then only the double self integrals are computed. 
%
%   These data are saved in tt.SS.  The integration is carried out using
%   analytical formulae for the inner integral and the Gaussian integration
%   for the outer integral.  The indices of the observation and integration 
%   faces are saved in FF.IS and FF.JS, respectively.
%
% Inputs:
%   P       - array of nodes
%   t       - array of metal faces
%   CoeffS  - node coefficients for a Gaussian formula
%   WeightsS- weights for a Gaussian formula
%   Radius  - threshold parameter - compared to the ratio distance 
%   between triangle centers/square root of two sizes. Each size is 
%   defined as a maximum distance from the center of the simplex to its vertex.
% Output:
%   tt.SS - array of potential integrals (divided by face areas) - scalar
%   tt.RS - array of potential integrals (divided by face areas) - with 
%   3x3 matrix elements (rho_i*rho_j) assembled as a 1D array 
%   tt.IS - indexes of observation faces
%   tt.JS - indexes of integration faces

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu
% Authors: S. Makarov, S. Kulkarni
