%WRAPPER - Wrapper for the basis functions
%
% Syntax:
%   wrapper
%
% Description:
%   WRAPPER calls DIELECTRIC, which returns a structure GEOM.  
%   WRAPPER calls METAL, which returns a structure geom.  
%   No action, other than running WRAPPER, is required of the user.
%   GEOM/geom specify all the parameters of the dielectric tetrahedra/metal
%   faces plus the system of basis functions including the potential
%   integrals.
%   
%   When it finishes, WRAPPER saves the following to basis.mat:
%
%   GEOM  - structure array describing the edge basis functions 
%   geom  - structure array describing the RWG basis functions const 
%   const - structure array of constants including dielectric data for
%       every tetrahedron 
%   FeedIndexes - indexes into feeding metal edges (for antenna radiation) 
%
%
%   See also DIELECTRIC and/or METAL in directory CODES.

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu  
% Authors: S. Kulkarni, A. Marut, S. Makarov 


clear all

s = pwd;
cd ..;
load    ('1_mesh/struct3d');
pathadd(s, 0);
cd(s);

tic
geom        = metal(P, t, Tp, Tm, Vp, Vm, Edgesm, const);
GEOM        = dielectric (P, t, T, Faces, FacesNontrivial, Edges, AT, const);
if ~isempty(geom)&~isempty(GEOM)
    GEOM    = f_basis(GEOM, geom, AT, FacesNontrivial, const);  
end
toc

disp([ 'Triangles:    ' num2str(size(t, 2))]);
disp([ 'Tets:         ' num2str(size(T, 2))]);

if ~isempty(geom)
    disp([ 'MetalEdges:   ' num2str(geom.EdgesTotal)]);
end
if ~isempty(GEOM)
    disp([ 'DielEdges:    ' num2str(GEOM.EdgesTotal)]);
end

cd ..
cd 3_mom
if  exist('cache.mat')
    delete('cache.mat');
end
if  exist('out.mat')
    delete('out.mat');
end
cd ..
cd 2_basis
save('basis', 'GEOM', 'geom', 'const', 'PortIndexes', 'AT', '-v7.3');
clear all