function [efield efieldv] = currentd(GEOM, D, const);
%CURRENTD - Outputs the total electric field (D/eps) for the dielectric volume.
%
% Syntax:
%   [efield] = currentd(GEOM, D, const);
%
% Description:
%   CURRENTD computes the electric field (polarization current) distrbution
%   within the dielectric volume
%
% Inputs:
%   GEOM - structure array that defines all the parameters of the
%       dielectric tetrahedra including basis functions
%   D - MoM solution vector
%
% Outputs:
%   efield  - vector of the total electric field for tetrahedra
%
% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu  
% Authors: S. Kulkarni, A. Marut, S. Makarov

%   Find MoM fields for every tetrahedron
for m = 1:GEOM.TetrahedraTotal
    efield(:, m) = [0; 0; 0];  
    for n =1:GEOM.EdgesTNI(m)
        M      = GEOM.EdgesTN(n, m);  %   base edge (global number)
        basis  = GEOM.BasisTC(:, n, m);            
        efield(:, m)  = efield(:,m) + D(M)*basis/const.Epsilon_r(m);    
    end
end
