% FIELDM - Computes electric field, magnetic field, and Poynting vector -
% metal
%
% Syntax:
%   [Poynting, E, H] = fieldm(const, GEOM, I, f, Points, Radius, OPTION);
%                      
% Description:
%   FIELDM computes scattered/total electric and magnetic field and the Poynting
%   vector for scattered/total field everywhere in space
%
% Inputs:
%   const   - structure array defining electromagnetic parameters
%   geom    - structure array that defines all the parameters of the
%       metal faces including basis functions
%   I       - MoM solution vector
%   f       - frequency of operation in Hz (real frequency only)
%   Points  - array of observation points where the fields are to be
%   computed
%   Radius  - parameter that defines the critical ratio of the observation
%   distance (distance from observation point to face center)
%   to the face size. At R = infinity, all volume/surface
%   integrals are computed with higher accuracy. R >=2 is recommended 
%   OPTION  - a parameter that is set to 0 to calculate the scattered
%   fields and to 1 to calculate total fields. This parameter has no effect 
%   for the eigenmode solution
%
%   
%   More detailed information on using FIELDM can be found in the
%   documentation
%
% Outputs:
%   Poynting - array of the Poynting vector (W/m^2) for scattered field
%   E - array of scattered electric field (complex vector at a point, V/m)
%   H - array of scattered magnetic field (complex vector at a point, A/m)            
%   All are of size (3-by-Points where the field is calculated).

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu  
% Authors: S. Kulkarni, A. Marut, S. Makarov
