%SLV - Computes condition number of the impedance matrix or the complete MoM solution
% Syntax:
%       OUTPUT = slv(Z, FLAG, V);
%       OUTPUT = slv(Z, 0);
%       OUTPUT = slv(Z, 1, V);
%
% Description:
%   SLV returns the reciprocal of the condition number of the complex
%   symmetric impedance matrix Z or the MoM solution D, where Z*D=V.
%
%   When FLAG is set to zero, SLV finds the reciprocal of the condition
%   number of the complex symmetric impedance matrix. This is used to obtain
%   the eigenmode solution.
%
%   When FLAG is set to one, SLV accepts a third argument which is the
%   voltage excitation vector V and outputs the current vector D. 
% 
%   SLV uses Intel Math Kernel Library's (MKL) LAPACK driver routine [1]
%   ZSYSV for solving system of linear equations with complex symmetric
%   matrices.
% 
%   SLV uses Intel MKL's LAPACK routines[1] to compute the estimate of the
%   reciprocal condition number:
%   ZLANSY calculates the value of the 1-norm, or the Frobenius norm, or
%   the infinity norm, or the element of largest absolute value of the
%   complex symmetric matrix. 
%   ZSYTRF computes the Bunch-Kaufman factorization of the complex
%   symmetric matrix.
%   ZSYCON estimates the reciprocal of the condition number of the complex
%   symmetric matrix.
%
% Inputs:
%   Z - complex symmetric square impedance matrix Z of dimension GEOM.EdgesTotal
%   FLAG - parameter controlling output
%   V - voltage excitation vector(1-by-GEOM.EdgesTotal)
%
% Outputs:
%   OUTPUT - When FLAG is 0, the reciprocal of the condition number of Z.
%            When FLAG is 1, 1-by-GEOM.EdgesTotal MoM solution vector D.
%
% References:
% [1] Intel Math Kernel Library Manual
%     http://www.intel.com/software/products/mkl/docs/manuals.htm

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu  
% Authors: S. Kulkarni, A. Marut, S. Makarov
