function varargout = viewfields(varargin)
%VIEWFIELDS - Creates 3-D plots of E, H, Poynting vector, and bound charge.
%
% Syntax:
%   viewfields(f_re, output, GEOM, fields);
%
% Description:
%   VIEWFIELDS allows the user to create 3-D plots of several physical
%   quantities.  The user can plot the x-, y-, and z-components as well as
%   magnitude of the electric field, magnetic field, and Poynting vector.
%   In addition, the user can plot the bound surface charge density for the
%   dielectric faces.
%
% Inputs:
%   f_re - the real part of the eigenfrequency of the resonator 
%   output - structure array containing the MoM solution vector D 
%   GEOM - structure array describing the geometry of the resonator 
%   and basis functions. See also ..\2_BASIS\DIELECTRIC.
%   fields - structure array containing the following fields:
%       E - array of the scattered electric field (V/m)
%       H - array of the scattered magnetic field (A/m)
%       Poynting - array of the Poynting vector (W/m^2) for scattered field

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu  
% Authors: A. Marut, S. Kulkarni, S. Makarov

% Last Modified by GUIDE v2.5 09-Jun-2005 14:06:16

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @viewfields_OpeningFcn, ...
                   'gui_OutputFcn',  @viewfields_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before viewfields is made visible.
function viewfields_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to viewfields (see VARARGIN)
handles.f_re             = varargin{1};
handles.geom             = varargin{2};
handles.GEOM             = varargin{3};
handles.fields           = varargin{4};

% Constants
handles.X = 1;
handles.Y = 2;
handles.Z = 3;
handles.MAGNITUDE = 4;

% Compute the magnitudes of E, H, and Poynting vector
handles.fields.E(4,:) = sqrt(dot(handles.fields.E, handles.fields.E));
handles.fields.H(4,:) = sqrt(dot(handles.fields.H, handles.fields.H));
handles.fields.Poynting(4,:) = sqrt(dot(handles.fields.Poynting, handles.fields.Poynting));
handles.fields.currentv(4,:)  = sqrt(dot(handles.fields.currentv, handles.fields.currentv));

% Choose default command line output for viewfields
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% Select the X-component and E-field radio buttons as if clicked
rb_magnit_Callback(handles.rb_magnit, [], guidata(hObject));
rb_show_E_Callback(handles.rb_show_E, [], guidata(hObject));

% UIWAIT makes viewfields wait for user response (see UIRESUME)
% uiwait(handles.figure1);

set(hObject, 'CloseRequestFcn', @restore_path);

% --- Outputs from this function are returned to the command line.
function varargout = viewfields_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in rb_x_comp.
function rb_x_comp_Callback(hObject, eventdata, handles)
% hObject    handle to rb_x_comp (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

select_vector_component_radio_button(hObject, eventdata, handles);
handles.selected_vector_component = handles.X;
guidata(hObject, handles);



% --- Executes on button press in rb_y_comp.
function rb_y_comp_Callback(hObject, eventdata, handles)
% hObject    handle to rb_y_comp (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

select_vector_component_radio_button(hObject, eventdata, handles);
handles.selected_vector_component = handles.Y;
guidata(hObject, handles);



% --- Executes on button press in rb_z_comp.
function rb_z_comp_Callback(hObject, eventdata, handles)
% hObject    handle to rb_z_comp (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

select_vector_component_radio_button(hObject, eventdata, handles);
handles.selected_vector_component = handles.Z;
guidata(hObject, handles);



% --- Executes on button press in rb_magnit.
function rb_magnit_Callback(hObject, eventdata, handles)
% hObject    handle to rb_magnit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

select_vector_component_radio_button(hObject, eventdata, handles);
handles.selected_vector_component = handles.MAGNITUDE;
guidata(hObject, handles);



% --- Executes on button press in rb_show_E.
function rb_show_E_Callback(hObject, eventdata, handles)
% hObject    handle to rb_show_E (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

select_physical_quantity_radio_button(hObject, eventdata, handles);
handles.selected_physical_quantity = 'E';
handles.title_text = 'MaxE(V/m) = ';    % Text portion of graph title
guidata(hObject, handles);



% --- Executes on button press in rb_show_H.
function rb_show_H_Callback(hObject, eventdata, handles)
% hObject    handle to rb_show_H (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

select_physical_quantity_radio_button(hObject, eventdata, handles);
handles.selected_physical_quantity = 'H';
handles.title_text = 'MaxH(A/m) = ';
guidata(hObject, handles);



% --- Executes on button press in rb_show_P.
function rb_show_P_Callback(hObject, eventdata, handles)
% hObject    handle to rb_show_P (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

select_physical_quantity_radio_button(hObject, eventdata, handles);
handles.selected_physical_quantity = 'Poynting';
handles.title_text = 'MaxP(W/m^2) = ';
guidata(hObject, handles);

% --- Executes on button press in rb_show_current.
function rb_show_current_Callback(hObject, eventdata, handles)
% hObject    handle to rb_show_P (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

select_physical_quantity_radio_button(hObject, eventdata, handles);
handles.selected_physical_quantity = 'currentv';
handles.title_text = 'MaxCurrent(A/m) = ';
guidata(hObject, handles);


% --- Executes on button press in rb_show_C.
function rb_show_C_Callback(hObject, eventdata, handles)
% hObject    handle to rb_show_C (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

select_physical_quantity_radio_button(hObject, eventdata, handles);
handles.selected_physical_quantity = 'C';
handles.title_text = 'abs(MaxC)(Coulomb/m^2) = ';
guidata(hObject, handles);

% --- Executes on button press in rb_show_CM.
function rb_show_CM_Callback(hObject, eventdata, handles)
% hObject    handle to rb_show_CM (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

select_physical_quantity_radio_button(hObject, eventdata, handles);
handles.selected_physical_quantity = 'CM';
handles.title_text = 'abs(MaxC)(Coulomb/m^2) = ';
guidata(hObject, handles);


function handles = select_vector_component_radio_button(hObject, eventdata, handles)
% hObject    handle to the radio button to select
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data

% Deselect the other radio buttons
set(handles.rb_x_comp, 'Value', get(handles.rb_x_comp, 'Min'));
set(handles.rb_y_comp, 'Value', get(handles.rb_y_comp, 'Min'));
set(handles.rb_z_comp, 'Value', get(handles.rb_z_comp, 'Min'));
set(handles.rb_magnit, 'Value', get(handles.rb_magnit, 'Min'));

% Select the chosen radio button
set(hObject, 'Value', get(hObject, 'Max'));



function handles = select_physical_quantity_radio_button(hObject, eventdata, handles)
% hObject    handle to the radio button to select
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data

% Deselect the other radio buttons
set(handles.rb_show_E, 'Value', get(handles.rb_show_E, 'Min'));
set(handles.rb_show_H, 'Value', get(handles.rb_show_H, 'Min'));
set(handles.rb_show_P, 'Value', get(handles.rb_show_H, 'Min'));
set(handles.rb_show_C, 'Value', get(handles.rb_show_C, 'Min'));
set(handles.rb_show_CM, 'Value', get(handles.rb_show_CM, 'Min'));
set(handles.rb_show_current, 'Value', get(handles.rb_show_current, 'Min'));
% Select the chosen radio button
set(hObject, 'Value', get(hObject, 'Max'));


% --- Executes on button press in btn_plot_graph.
function btn_plot_graph_Callback(hObject, eventdata, handles)
% hObject    handle to btn_plot_graph (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
figure;
if strcmpi(handles.selected_physical_quantity, 'C')
    handles = plot_charge(handles);
elseif strcmpi(handles.selected_physical_quantity, 'CM')
    handles = plot_chargem(handles);
else
    handles = plot_field(handles);
end
xlabel('x');
ylabel('y');
zlabel('z');
colorbar('vert');
title(strcat(handles.title_text, num2str(handles.max_val,3)));

function handles = plot_field(handles)
field            = getfield(handles.fields, handles.selected_physical_quantity);
Color            =   abs(field(handles.selected_vector_component,:));
handles.max_val  =   max(Color);              
if strcmpi(handles.selected_physical_quantity, 'currentv')
    if ~isempty(handles.geom)
        viewer(handles.geom.P, handles.geom.t, Color);
    end
else
    if ~isempty(handles.GEOM)
        X               = [handles.GEOM.P(1,:)' handles.GEOM.P(2,:)' handles.GEOM.P(3,:)'];                         
        tetramesh(handles.GEOM.T',X, Color,'FaceAlpha',0.25,'EdgeAlpha',0.25,'EdgeColor',[0 0 0]);
    end
end

function handles = plot_charge(handles)
handles.max_val = 0;
if ~isempty(handles.GEOM)
    charge_d            =   real(handles.fields.chargedv);
    handles.max_val     =   max(abs(charge_d));
    Color               =   charge_d;
    viewer(handles.GEOM.P, handles.GEOM.Faces(:, 1:handles.GEOM.FacesNontrivial), Color);
end

function handles = plot_chargem(handles)
charge_m            =   real(handles.fields.chargemv);
handles.max_val     =   max(abs(charge_m));
Color               =   charge_m;
if ~isempty(handles.geom)
    viewer(handles.geom.P, handles.geom.t, Color);
end

function restore_path(varargin)
s = pwd;
cd ..;
pathremove;
cd(s);
delete(gcf);



