%ZMD - Computes the impedance matrix for metal/dielectric structures.
%
% Syntax:
%    Z = zmd(geom, GEOM, const, omega_re, omega_im);
% 
% Description: 
%   ZMD returns matrix Z, which corresponds to the impedance matrix for
%   pure dielectric structures. 
%
% Inputs:
%   GEOM - structure array that defines all the parameters of the
%       dielectric tetrahedra including potential integrals
%   const - structure array defining electromagnetic parameters
%   omega_re - real part of the angular frequency of operation
%   omega_im - imaginary part of the angular frequency of operation
%
% Outputs:
%   Z - GEOM.Edgestotal-by-GEOM.Edgestotal impedance matrix
%   To convert the Z-matrix to the standard MATLAB form, the following
%   code can be used:
%
%   Z       = Z(1:2:length(Z)) + j*Z(2:2:length(Z));
%   dim     = geom.EdgesTotal + GEOM.EdgesTotal;
%   Z       = reshape(Z, [dim, dim]);

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu  
% Authors: S. Kulkarni, A. Marut, S. Makarov