%ZMDSLV - Computes the complete MoM solution or reciprocal of condition number of impedance matrix.
%
% Syntax:
%   output = ZMDSLV(geom, GEOM, const, omega_re, omega_im, flag, V, Termination);
%
% Description:
%   ZMDSLV calculates the impedance matrix and solves the system of MoM
%   equations to obtain the MoM solution vector or returns the reciprocal
%   of the condition number of the complex symmetric impedance matrix.
%   ZMDSLV is a combination of ZMD and SLV that does not output the
%   impedance matrix to the MATLAB workspace. When FLAG is set to zero,
%   ZMDSLV finds the condition number of the complex symmetric impedance
%   matrix and ignores further input arguments.  This is used to obtain the
%   eigenmode solution.  When FLAG is set to one, ZMDSLV accepts a third
%   argument which is the voltage vector V and outputs the MoM solution
%   vector.
%
%   Used by EIGENFREQ and IMPEDANCE.
%	
% Inputs:
%   geom - structure array that defines all the parameters of the
%       metal faces including RWG basis functions
%   GEOM - structure array that defines all the parameters of the
%       dielectric tetrahedra including basis functions
%   const - structure array defining electromagnetic parameters
%   omega_re - real part of angular frequency
%   omega_im - imaginary part of angular frequency
%   flag - parameter controlling output
%   V - voltage excitation vector(1-by-geom.EdgesTotal + GEOM.EdgesTotal)
%   Tertimination - termination edge numbers - 50 Ohm - the impedance matrix 
%   is modified accordingly. 
%
% Outputs:
%   output - When FLAG is 0, the reciprocal of the condition number of Z.
%            When FLAG is 1, 1-by-geom.EdgesTotal + GEOM.EdgesTotal array of the currents in
%                            the dielectric (volume polarization current)
%                            and on the metal surface (surface current density)

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu  
% Authors: S. Kulkarni, A. Marut, S. Makarov
