%SCATTERFIELD - Interactive nearfield viewer
%
% Syntax:
%   scatterfield
%
% Description:
%   SCATTERFIELD plot the fields/currents/charges within the antenna resonator 
%   or on its surface at plane wave incidence. SHOULD be executed after 
%   EIGENFREQ. Only an incident plane wave is allowed as an excitation.
%
% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu  
% Authors: S. Kulkarni, A. Marut, S. Makarov


s = pwd;
cd ..;
load('2_basis/basis');
pathadd(s, 0);
cd(s); 

VM = [];
VD = [];
if ~isempty(geom)
    pol     = repmat(E0, [1, geom.TrianglesTotal]);
    dir     = repmat(dir0, [1, geom.TrianglesTotal]);
    kr      = dot(dir, geom.PointsFC, 1);
    Einc    = pol.*repmat(exp(-j*kr), [3, 1]) + j*1e-64;
    VM      = voltagem(geom, Einc);
    
end
if ~isempty(GEOM)
    pol     = repmat(E0, [1, GEOM.TetrahedraTotal]);
    dir     = repmat(dir0, [1, GEOM.TetrahedraTotal]);
    kr      = dot(dir, GEOM.CenterT, 1);
    Einc    = pol.*repmat(exp(-j*kr), [3, 1]) + j*1e-64;
    VD      = voltaged(GEOM, Einc);
end
V = [VM; VD];

output      = zmdslv(geom, GEOM, const, 2*pi*freq, 0.0, 1, V, []);      
I = []; 
D = [];
current  = [];
currentv = [];
chargemv = [];
chargedv = [];

if (~isempty(geom))
    output(1:geom.EdgesTotal) = j*omega_re*output(1:geom.EdgesTotal);
    I   = output(1:geom.EdgesTotal);   
    
    %   Find electric current distribution
    [current, currentv]     = currentm(geom, I);

    %   Find free electric charge distribution
    [dummy, chargemv]     = chargem(geom, I, freq);    
end

if ~isempty(GEOM)
    D   = output(length(I)+1:end);    
    %   Define observation points
    Points          = GEOM.CenterT; 

    %   Find field solution using E/M potentials 
    flag = 0;   % only scattered field
    [E, H, Poynting] = field(geom, GEOM, const, output, freq, Points, flag);

    %   Find electric field using the MoM solution directly
    Efield           = currentd(GEOM, D, const);
    Error            = norm(Efield-E)/norm(Efield) % can be (very) large

    %   Find bound charge distribution 
    [dummy chargedv]  = charged(GEOM, D);
else
    E = []; H = []; Poynting = []; chargedv = [];
end    
    


%   Create near field data 
fields = struct('Poynting', Poynting, ...
                'E', E, ...
                'H', H, ...
                'currentv', currentv, ...
                'chargemv', chargemv, ...
                'chargedv', chargedv);

viewfields(freq, geom, GEOM, fields);

% PATHREMOVE is not called here because the directories must remain in the
% path as long as the VIEWFIELDS window is open.
