function pathadd(start_dir, flag)
%PATHADD Add MAT05 directories to the path
%
% Syntax:
%   pathadd(start_dir, flag)
%
% Description:
%   PATHADD adds MAT05 directories to the path.  It adds START_DIR and the
%   directory named 'codes' immediately below START_DIR.  If FLAG is
%   equivalent to TRUE, then PATHADD also adds the version-specific
%   directory immediately below the 'codes' directory.
%
%   PATHADD uses the global variable MAT05_PATH_DIRECTORIES.
%
%   PATHADD assumes that all directories to be added (except for a
%   directory corresponding to an unsupported version of MATLAB) exist.
%
% Input:
%   START_DIR - String containing the highest directory to add to the path.
%   FLAG - Logical stating whether to add the version-specific directory.

% MATLAB Antenna Toolbox Draft 05, Antenna Lab, ECE, WPI, mat05@ece.wpi.edu
% Author: A. Marut

global MAT05_PATH_DIRECTORIES;

codes_dir_full = fullfile(start_dir, 'codes');
MAT05_PATH_DIRECTORIES = {start_dir, codes_dir_full};
addpath(start_dir, codes_dir_full);

if ~flag
    return
end

vers = ver('MATLAB');
switch vers.Version
    case '6.5.0'
        vers_dir = 'version650';
    case '7.0.0'
        vers_dir = 'version700';
    case '7.0.1'
        vers_dir = 'version701';
    case '7.0.4'
        vers_dir = 'version704';
    case '8.0.0'
        vers_dir = 'version800';
    otherwise
        warning(['MATLAB version '  vers.Version  ' is not supported.']);
end
vers_dir_full  = fullfile(codes_dir_full, vers_dir);
MAT05_PATH_DIRECTORIES{3} = vers_dir_full;
addpath(vers_dir_full);

